@@ -1,13 +1,13 @@
 use strict;
 use warnings;
-no if "$]" >= 5.031008, feature => 'indirect';
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.153-3-g721a01f
-# vim: set ts=8 sts=4 sw=4 tw=115 et :
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.154-9-gb295fed
+# vim: set ts=8 sts=4 sw=4 tw=100 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.154';
+our $VERSION = '0.155';
 
+no if "$]" >= 5.031009, feature => 'indirect';
 use Moose;
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -598,7 +598,9 @@ around add_plugins => sub {
         }
 
         # record prereq (and version) for later possible injection
-        $self->_add_minimum_plugin_requirement($plugin => $payload->{':version'} // 0);
+        # (Note: this depends on $CWD being equal to $zilla->root)
+        $self->_add_minimum_plugin_requirement($plugin => $payload->{':version'} // 0)
+            if not -f do { (my $filename = $plugin) =~ s{::}{/}g; $filename .= '.pm' };
     }
 
     return $self->$orig(@plugins);
@@ -649,7 +651,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.154
+version 0.155
 
 =head1 SYNOPSIS
 
